# from pathlib import Path
#
# from i3configger import base, build
#
# HERE = Path(__file__).parent
# EXAMPLES = HERE.parent / 'examples'
# TARGET = HERE / 'target'
#
#
# def test_build():
#     base.DEBUG = 0
#     builder = build.Builder()
#     builder.build()
